==> minitube-0.9.tar.gz: minitube/locale/lat.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="lv_LV" sourcelanguage="en_US">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Arī ārpus web pārlūka ir dzīve!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Versija %1</translation>
    </message>
    <message>
        <source>This is a &quot;Technology Preview&quot; release, do not expect it to be perfect.</source>
        <translation>Šis ir &quot;Technology Preview&quot; izlaidums, negaidiet no tā brīnumus.</translation>
    </message>
    <message>
        <source>Report bugs and send in your ideas to %1</source>
        <translation>Ziņojiet par kļūdām un iesūtiet idejas: %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 ir Bezmaksas Programma, taču tās izstrāde prasa dārgu laiku.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate via PayPal&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Lūdzu, &lt;a href=&apos;%1&apos;&gt;ziedojiet ar PayPal&lt;/a&gt;, lai atbalstītu %2 turpmāku izstrādi.</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Ikonu izveidoja %1.</translation>
    </message>
    <message>
        <source>Compact mode contributed by %1.</source>
        <translation>Kompakto režīmu iespējoja %1.</translation>
    </message>
    <message>
        <source>HTTP proxy support contributed by %1.</source>
        <translation>HTTP proxy atbalstu iespējoja by %1.</translation>
    </message>
    <message>
        <source>Windows version built by %1</source>
        <translation type="obsolete">Windows versiju izveidoja %1</translation>
    </message>
    <message>
        <source>Translated by %1</source>
        <translation>Pārtulkoja %1</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Licencēts pēc &lt;a href=&apos;%1&apos;&gt;GNU Vispārējās Publiskās Licences&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Aizvērt</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Par</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>Ko jūs vienmēr vēlējāties zināt par %1, taču neuzdrošinājāties pajautāt</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Dzēst</translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <source>Searching...</source>
        <translation>Meklē...</translation>
    </message>
    <message>
        <source>Show %1 More</source>
        <translation>Parādīt vairāk no %1</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Nav klipu</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Vairs nav klipu</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Kļūda</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation>Atpakaļ</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation>Atgriezties iepriekšējā logā</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>Apturēt</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Apturēt atskaņošanu un atgriezties meklēšanas logā</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>Izlaist</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Pārlēkt uz nākamo klipu</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>Pauze</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Apturēt</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>Pilnekrāna režīms</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Ieslēgt pilnekrāna režīmu</translation>
    </message>
    <message>
        <source>&amp;Compact mode</source>
        <translation>Kompaktais režīms</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Paslēpt klipu sarakstu un rīkjoslu</translation>
    </message>
    <message>
        <source>&amp;YouTube</source>
        <translation>YouTube</translation>
    </message>
    <message>
        <source>Open the YouTube video page</source>
        <translation>Atvērt YouTube vietni</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>Izņemt</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Izņemt atzīmētos klipus</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Pārcelt augšup</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Pārcelt atzīmētos klipus augšup</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Pārcelt lejup</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Pārcelt atzīmētos klipus lejup</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>Beigt darbu</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Visu labu</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>Tīmekļa vietne</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 tīmeklī</translation>
    </message>
    <message>
        <source>&amp;Donate via PayPal</source>
        <translation>Ziedojiet ar PayPal</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Lūdzu, atbalstiet %1 turpmāku izstrādi</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>Par</translation>
    </message>
    <message>
        <source>Info par %1</source>
        <translation type="obsolete">Ziņas par</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Meklēt</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Izslēgt skaņu</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>Klipu saraksts</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>Klips</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Palīdzība</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Nospiediet %1 lai palielinātu skaļumu, %2 lai to samazinātu</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Atvēru %1</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>Nenovēršama kļūda: %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Kļūda: %1</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>Atskaņot</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Turpināt atskaņošanu</translation>
    </message>
    <message>
        <source>Exit &amp;Full Screen</source>
        <translation>Pārslēgties pilnekrāna režīmā</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Atlikušais laiks: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Skaļuma līmenis: %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Skaņa ir atslēgta</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Skaņa ir ieslēgta</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Ziņas par %1</translation>
    </message>
    <message>
        <source>High Definition video is enabled</source>
        <translation>Augstā izšķirtspēja ir ieslēgta</translation>
    </message>
    <message>
        <source>High Definition video is not enabled</source>
	<translation>Augstā izšķirtspēja nav ieslēgta</translation>
    </message>
    <message>
        <source>The current video is in High Definition</source>
        <translation>Šis ir augstās izšķirtspējas video</translation>
    </message>
    <message>
        <source>The current video is not in High Definition</source>
	<translation>Šis nav augstās izšķirtspējas video</translation>
    </message>
    <message>
        <source>&amp;Clear recent keywords</source>
        <translation>Dzēst atslēgvārdu vēsturi</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>Programma</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Most relevant</source>
        <translation>Atbilstošākie</translation>
    </message>
    <message>
        <source>Most recent</source>
        <translation>Jaunākie</translation>
    </message>
    <message>
        <source>Most viewed</source>
        <translation>Apmeklētākie</translation>
    </message>
    <message>
        <source>You&apos;re watching &quot;%1&quot;</source>
        <translation>Jūs skatāties &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>NetworkAccess</name>
    <message>
        <source>Network error: %1</source>
        <translation>Tīkla kļūda: %1</translation>
    </message>
</context>
<context>
    <name>PrettyItemDelegate</name>
    <message>
        <source>%1 views</source>
        <translation>%1 skatījumi</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Meklēt</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Laipni lūdzam &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>Enter a keyword to start watching videos.</source>
        <translation>Ierakstiet atslēgvārdu lai sāktu skatīties klipus</translation>
    </message>
    <message>
        <source>Watch</source>
        <translation>Skatīties</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Iepriekšējie atslēgvārdi</translation>
    </message>
    <message>
        <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
        <translation>%1 jaunā versija ir pieejama. Lūdzu, &lt;a href=&apos;%2&apos;&gt;atjauniniet pret %3 versiju&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Jūsu ērtībai</translation>
    </message>
</context>
<context>
    <name>SettingsView</name>
    <message>
        <source>Preferences</source>
        <translation>Uzstādījumi</translation>
    </message>
</context>
<context>
    <name>Video</name>
    <message>
        <source>Network error: %1 for %2</source>
        <translation>Tīkla kļūda: %1 ar %2</translation>
    </message>
</context>
</TS>

==> minitube-1.0.tar.gz: minitube/locale/lat.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="lv_LV" sourcelanguage="en_US">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Arī ārpus web pārlūka ir dzīve!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Versija %1</translation>
    </message>
    <message>
        <source>This is a &quot;Technology Preview&quot; release, do not expect it to be perfect.</source>
        <translation>Šis ir priekšapskates izlaidums, negaidiet no tā brīnumus.</translation>
    </message>
    <message>
        <source>Report bugs and send in your ideas to %1</source>
        <translation>Ziņojiet par kļūdām un iesūtiet idejas: %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 ir Bezmaksas Programma, taču tās izstrāde prasa dārgu laiku.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate via PayPal&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Lūdzu, &lt;a href=&apos;%1&apos;&gt;ziedojiet ar PayPal&lt;/a&gt;, lai atbalstītu %2 turpmāku izstrādi.</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Ikonu izveidoja %1.</translation>
    </message>
    <message>
        <source>Compact mode contributed by %1.</source>
        <translation>Kompakto režīmu iespējoja %1.</translation>
    </message>
    <message>
        <source>HTTP proxy support contributed by %1.</source>
        <translation>HTTP proxy atbalstu iespējoja by %1.</translation>
    </message>
    <message>
        <source>Windows version built by %1</source>
        <translation>Windows versiju izveidoja %1</translation>
    </message>
    <message>
        <source>Translated by %1</source>
        <translation>Pārtulkoja %1</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Licencēts pēc &lt;a href=&apos;%1&apos;&gt;GNU Vispārējās Publiskās Licences&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Aizvērt</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Par</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>Ko jūs vienmēr vēlējāties zināt par %1, taču neuzdrošinājāties pajautāt</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
	<translation>Lūdzu, &lt;a href=&apos;%1&apos;&gt;ziedojiet&lt;/a&gt;, lai atbalstītu %2 turpmāku izstrādi.</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Dzēst</translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <source>Searching...</source>
        <translation>Meklē...</translation>
    </message>
    <message>
        <source>Show %1 More</source>
        <translation>Parādīt vairāk no %1</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Nav klipu</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Vairs nav klipu</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Kļūda</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation>Atpakaļ</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation>Atgriezties iepriekšējā skatā</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>Apturēt</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Apturēt atskaņošanu un atgriezties meklēšanas logā</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>Izlaist</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Pārlēkt uz nākamo klipu</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>Pauze</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Apturēt</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>Pilnekrāna režīms</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Ieslēgt pilnekrāna režīmu</translation>
    </message>
    <message>
        <source>&amp;Compact mode</source>
        <translation>Kompaktais režīms</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Paslēpt klipu sarakstu un rīkjoslu</translation>
    </message>
    <message>
        <source>&amp;YouTube</source>
	<translation>&amp;YouTube</translation>
    </message>
    <message>
        <source>Open the YouTube video page</source>
        <translation>Atvērt YouTube vietni</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>Izņemt</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Izņemt atzīmētos klipus</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Pārcelt augšup</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Pārcelt atzīmētos klipus augšup</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Pārcelt lejup</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Pārcelt atzīmētos klipus lejup</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>Beigt darbu</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Visu labu</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>Tīmekļa vietne</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 tīmeklī</translation>
    </message>
    <message>
        <source>&amp;Donate via PayPal</source>
        <translation>Ziedojiet ar PayPal</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Lūdzu, atbalstiet %1 turpmāku izstrādi</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>Par</translation>
    </message>
    <message>
        <source>Info par %1</source>
        <translation>Ziņas par %1</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Meklēt</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Izslēgt skaņu</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>Klipu saraksts</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>Klips</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Palīdzība</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Nospiediet %1 lai palielinātu skaļumu, %2 lai to samazinātu</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Atvēru %1</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>Nenovēršama kļūda: %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Kļūda: %1</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>Atskaņot</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Turpināt atskaņošanu</translation>
    </message>
    <message>
        <source>Exit &amp;Full Screen</source>
        <translation>Pārslēgties pilnekrāna režīmā</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Atlikušais laiks: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Skaļuma līmenis: %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Skaņa ir atslēgta</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Skaņa ir ieslēgta</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Ziņas par %1</translation>
    </message>
    <message>
        <source>High Definition video is enabled</source>
        <translation>Augstā izšķirtspēja ir ieslēgta</translation>
    </message>
    <message>
        <source>High Definition video is not enabled</source>
        <translation>Augstā izšķirtspēja nav ieslēgta</translation>
    </message>
    <message>
        <source>The current video is in High Definition</source>
        <translation>Šis ir augstās izšķirtspējas video</translation>
    </message>
    <message>
        <source>The current video is not in High Definition</source>
        <translation>Šis nav augstās izšķirtspējas video</translation>
    </message>
    <message>
        <source>&amp;Clear recent keywords</source>
        <translation>Dzēst atslēgvārdu vēsturi</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>Programma</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Dzēst meklēšanas vēsturi. Šī rīcība būs neatgriezeniska.</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>Jūsu privātums tagad ir drošībā</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube page</source>
	<translation>Atvērt &amp;YouTube vietni</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Doties uz YouTube video vietni un apturēt atskaņošanu</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;link</source>
        <translation>Nokopēt YouTube norādi</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Nokopēt esošā klipa YouTube norādi starpliktuvē</translation>
    </message>
    <message>
        <source>Copy the video stream &amp;URL</source>
	<translation>Nokopēt video plūsmas &amp;URL</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
	<translation>Nokopēt esošās video plūsmas URL starpliktuvē</translation>
    </message>
    <message>
        <source>Make a &amp;donation</source>
        <translation>Ziedot</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>Klipa maksimālā izšķirtspēja ir %1</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Most relevant</source>
        <translation>Atbilstošākie</translation>
    </message>
    <message>
        <source>Most recent</source>
        <translation>Jaunākie</translation>
    </message>
    <message>
        <source>Most viewed</source>
        <translation>Apmeklētākie</translation>
    </message>
    <message>
        <source>You&apos;re watching &quot;%1&quot;</source>
        <translation>Jūs skatāties &quot;%1&quot;</translation>
    </message>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Tagad varat ielīmēt YouTube norādi citā programmā</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
	<translation>Tagad varat ielīmēt video plūsmas URL citā programmā</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>Norāde būs derīga tikai ierobežotu laiku</translation>
    </message>
</context>
<context>
    <name>NetworkAccess</name>
    <message>
        <source>Network error: %1</source>
        <translation>Tīkla kļūda: %1</translation>
    </message>
</context>
<context>
    <name>PrettyItemDelegate</name>
    <message>
        <source>%1 views</source>
        <translation>%1 skatījumi</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Meklēt</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Laipni lūdzam &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>Enter a keyword to start watching videos.</source>
        <translation>Ierakstiet atslēgvārdu lai sāktu skatīties klipus</translation>
    </message>
    <message>
        <source>Watch</source>
        <translation>Skatīties</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Iepriekšējie atslēgvārdi</translation>
    </message>
    <message>
        <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
        <translation>%1 jaunā versija ir pieejama. Lūdzu, &lt;a href=&apos;%2&apos;&gt;atjauniniet pret %3 versiju&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Jūsu ērtībai</translation>
    </message>
</context>
<context>
    <name>SettingsView</name>
    <message>
        <source>Preferences</source>
        <translation>Uzstādījumi</translation>
    </message>
</context>
<context>
    <name>Video</name>
    <message>
        <source>Network error: %1 for %2</source>
        <translation>Tīkla kļūda: %1 ar %2</translation>
    </message>
</context>
</TS>
